==> ver.B.b14.02.tar.gz: ver.B.b14.02/env/src/utils/get_url_filepath.c <==
/**********************************************************************
 
	Copyright (C) 2003 Hirohisa MORI <joshua@nichibun.ac.jp>
 
	This program is free software; you can redistribute it 
	and/or modify it under the terms of the GLOBALBASE 
	Library General Public License (G-LGPL) as published by 

	http://www.globalbase.org/
 
	This program is distributed in the hope that it will be 
	useful, but WITHOUT ANY WARRANTY; without even the 
	implied warranty of MERCHANTABILITY or FITNESS FOR A 
	PARTICULAR PURPOSE.

**********************************************************************/



#include	<stdlib.h>
#include	"memory_debug.h"
#include	"utils.h"

L_CHAR * seek_ptr();

L_CHAR *
get_url_filepath(URL * u)
{
L_CHAR * buf;
L_CHAR * ptr;
	buf = d_alloc(
		((u->db ? l_strlen(u->db) : 0) +
		 (u->name ? l_strlen(u->db) : 0) +
		 (u->query ? l_strlen(u->db) : 0) +
		 (u->resource ? l_strlen(u->resource) : 0) + 100) *
			sizeof(L_CHAR));
	buf[0] = 0;
	ptr = buf;
/* db: */
	if ( u->db == 0 ) {
		*ptr ++ = '/';
	}
	else {
		if ( u->db[0] != '/' )
			*ptr ++ = '/';
		l_strcpy(ptr,u->db);
		ptr = seek_ptr(ptr);
	}
	if ( *(ptr-1) != '/' )
		*ptr ++ = '/';
/* resource: */
	*ptr = 0;
	if ( u->resource ) {
		l_strcpy(ptr,u->resource);
		ptr = seek_ptr(ptr);
	}
/* query: */
	if ( u->query ) {
		*ptr ++ = '?';
		l_strcpy(ptr,u->query);
		ptr = seek_ptr(ptr);
	}
	if ( u->name ) {
		*ptr ++ = '#';
		l_strcpy(ptr,u->name);
		ptr = seek_ptr(ptr);
	}

	buf = d_re_alloc(buf,(l_strlen(buf)+1)*sizeof(L_CHAR));
	return buf;
/* err: */
	d_f_ree(buf);
	return 0;
}

==> ver.B.b16.07.tar.gz: ver.B.b16.07/env/src/utils/get_url_filepath.c <==
/**********************************************************************
 
	Copyright (C) 2003 Hirohisa MORI <joshua@nichibun.ac.jp>
 
	This program is free software; you can redistribute it 
	and/or modify it under the terms of the GLOBALBASE 
	Library General Public License (G-LGPL) as published by 

	http://www.globalbase.org/
 
	This program is distributed in the hope that it will be 
	useful, but WITHOUT ANY WARRANTY; without even the 
	implied warranty of MERCHANTABILITY or FITNESS FOR A 
	PARTICULAR PURPOSE.

**********************************************************************/



#include	<stdlib.h>
#include	"memory_debug.h"
#include	"utils.h"

L_CHAR * seek_ptr();

L_CHAR *
get_url_filepath(URL * u)
{
L_CHAR * buf;
L_CHAR * ptr;
	buf = d_alloc(
		((u->db ? l_strlen(u->db) : 0) +
		 (u->name ? l_strlen(u->db) : 0) +
		 (u->query ? l_strlen(u->query) : 0) +
		 (u->resource ? l_strlen(u->resource) : 0) + 100) *
			sizeof(L_CHAR));
	buf[0] = 0;
	ptr = buf;
/* db: */
	if ( u->db == 0 ) {
		*ptr ++ = '/';
	}
	else {
		if ( u->db[0] != '/' )
			*ptr ++ = '/';
		l_strcpy(ptr,u->db);
		ptr = seek_ptr(ptr);
	}
	if ( *(ptr-1) != '/' )
		*ptr ++ = '/';
/* resource: */
	*ptr = 0;
	if ( u->resource ) {
		l_strcpy(ptr,u->resource);
		ptr = seek_ptr(ptr);
	}
/* query: */
	if ( u->query ) {
		*ptr ++ = '?';
		l_strcpy(ptr,u->query);
		ptr = seek_ptr(ptr);
	}
	if ( u->name ) {
		*ptr ++ = '#';
		l_strcpy(ptr,u->name);
		ptr = seek_ptr(ptr);
	}

	buf = d_re_alloc(buf,(l_strlen(buf)+1)*sizeof(L_CHAR));
	return buf;
/* err: */
	d_f_ree(buf);
	return 0;
}
